pecos.simulators.sparsesim.cmd\_init
====================================

.. automodule:: pecos.simulators.sparsesim.cmd_init







   .. rubric:: Functions

   .. autosummary::

      init_minus
      init_minusi
      init_one
      init_plus
      init_plusi
      init_zero
